@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 1994-2023 The Octave Project Developers
+## Copyright (C) 1994-2025 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -118,8 +118,6 @@
 ## Turn tick labels off for all axes.
 ## @end table
 ##
-## Note: If there are no tick marks for an axes then there can be no labels.
-##
 ## @noindent
 ## The following options affect the direction of increasing values on the axes.
 ##
@@ -158,7 +156,7 @@
 ## axis ("tic", "labely");
 ## @end example
 ##
-## @seealso{xlim, ylim, zlim, caxis, daspect, pbaspect, box, grid}
+## @seealso{xlim, ylim, zlim, clim, daspect, pbaspect, box, grid}
 ## @end deftypefn
 
 function limits = axis (varargin)
@@ -390,7 +388,7 @@ function limits = __axis__ (ca, varargin)
       endif
 
       if (len > 7)
-        caxis (ca, opt(7:8));
+        clim (ca, opt(7:8));
       endif
 
     else
